#!/usr/bin/env python
#
# __init__.py - fsl.data package.
#
# Author: Paul McCarthy <pauldmccarthy@gmail.com>
#
"""This module contains various data types and associated I/O routines,
models, constants, and other data-like things used throughout ``fslpy``.
"""


from .utils import (guessType,  # noqa
                    makeWriteable)
